---
name: Feature Request
about: Submit a proposal/request for a new feature
title: ''
labels: feature request
assignees: ''

---

### Feature

<!-- A clear and concise description of the feature proposal -->

### Motivation

<!-- Please outline the motivation for the proposal. Is your feature request related to a problem? e.g., I'm always frustrated when [...]. If this is related to another GitHub issue, please link here too -->
